@@ -1,7 +1,7 @@
 // qsynth.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -44,12 +44,6 @@ const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
 #define CONFIG_DATADIR CONFIG_PREFIX "/share"
 #endif
 
-#if defined(LOCALEDIR)
-#define CONFIG_LOCALEDIR CONFIG_QUOTED(LOCALEDIR)
-#else
-#define CONFIG_LOCALEDIR CONFIG_DATADIR "/locale"
-#endif
-
 
 //-------------------------------------------------------------------------
 // Singleton application instance stuff (Qt/X11 only atm.)
@@ -99,7 +93,7 @@ public:
 			if (m_pMyTranslator->load(sLocName, sLocPath)) {
 				QApplication::installTranslator(m_pMyTranslator);
 			} else {
-				sLocPath = CONFIG_LOCALEDIR;
+				sLocPath = CONFIG_DATADIR "/qsynth/translations";
 				if (m_pMyTranslator->load(sLocName, sLocPath)) {
 					QApplication::installTranslator(m_pMyTranslator);
 				} else {
@@ -384,10 +378,8 @@ int main ( int argc, char **argv )
 	}
 
 	// Set default base font...
-	int iBaseFontSize = app.font().pointSize();
 	if (settings.iBaseFontSize > 0)
-		iBaseFontSize = settings.iBaseFontSize;
-	app.setFont(QFont(app.font().family(), iBaseFontSize));
+		app.setFont(QFont(app.font().family(), settings.iBaseFontSize));
 
 	// What style do we create these forms?
 	Qt::WindowFlags wflags = Qt::Window
