@@ -1,7 +1,7 @@
 // qsynthOptions.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2012, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -71,6 +71,7 @@ void qsynthOptions::loadOptions (void)
 	bStdoutCapture  = m_settings.value("/StdoutCapture", true).toBool();
 	bOutputMeters   = m_settings.value("/OutputMeters", false).toBool();
 	bSystemTray     = m_settings.value("/SystemTray", false).toBool();
+	bSystemTrayQueryClose = m_settings.value("/SystemTrayQueryClsoe", true).toBool();
 	bStartMinimized = m_settings.value("/StartMinimized", false).toBool();
 	iBaseFontSize   = m_settings.value("/BaseFontSize", 0).toInt();
 	iKnobStyle      = m_settings.value("/KnobStyle", 0).toInt();
@@ -136,6 +137,7 @@ void qsynthOptions::saveOptions (void)
 	m_settings.setValue("/StdoutCapture", bStdoutCapture);
 	m_settings.setValue("/OutputMeters", bOutputMeters);
 	m_settings.setValue("/SystemTray", bSystemTray);
+	m_settings.setValue("/SystemTrayQueryClose", bSystemTrayQueryClose);
 	m_settings.setValue("/StartMinimized", bStartMinimized);
 	m_settings.setValue("/BaseFontSize", iBaseFontSize);
 	m_settings.setValue("/KnobStyle", iKnobStyle);
@@ -218,19 +220,22 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 	QTextStream out(stderr);
 	const QString sEol = "\n\n";
 	int iSoundFontOverride = 0;
-	int argc = args.count();
+	const int argc = args.count();
 
 	for (int i = 1; i < argc; ++i) {
 
 		QString sVal;
 		QString sArg = args.at(i);
-		int iEqual = sArg.indexOf('=');
+		const int iEqual = sArg.indexOf('=');
 		if (iEqual >= 0) {
 			sVal = sArg.right(sArg.length() - iEqual - 1);
 			sArg = sArg.left(iEqual);
 		}
-		else if (i < argc - 1)
+		else if (i < argc - 1) {
 			sVal = args.at(i + 1);
+			if (sVal[0] == '-')
+				sVal.clear();
+		}
 
 		if (sArg == "-n" || sArg == "--no-midi-in") {
 			m_pDefaultSetup->bMidiIn = false;
@@ -312,21 +317,21 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 		}
 		else if (sArg == "-R" || sArg == "--reverb") {
 			if (sVal.isEmpty()) {
-				out << QObject::tr("Option -R requires an argument (reverb).") + sEol;
-				return false;
+				m_pDefaultSetup->bReverbActive = true;
+			} else {
+				m_pDefaultSetup->bReverbActive = !(sVal == "0" || sVal == "no" || sVal == "off");
+				if (iEqual < 0)
+					i++;
 			}
-			m_pDefaultSetup->bReverbActive = !(sVal == "0" || sVal == "no" || sVal == "off");
-			if (iEqual < 0)
-				i++;
 		}
 		else if (sArg == "-C" || sArg == "--chorus") {
 			if (sVal.isEmpty()) {
-				out << QObject::tr("Option -C requires an argument (chorus).") + sEol;
-				return false;
+				m_pDefaultSetup->bChorusActive = true;
+			} else {
+				m_pDefaultSetup->bChorusActive = !(sVal == "0" || sVal == "no" || sVal == "off");
+				if (iEqual < 0)
+					i++;
 			}
-			m_pDefaultSetup->bChorusActive = !(sVal == "0" || sVal == "no" || sVal == "off");
-			if (iEqual < 0)
-				i++;
 		}
 		else if (sArg == "-g" || sArg == "--gain") {
 			if (sVal.isEmpty()) {
@@ -364,14 +369,13 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 			out << QObject::tr("Qt: %1\n").arg(qVersion());
 			out << QObject::tr(QSYNTH_TITLE ": %1\n").arg(QSYNTH_VERSION);
 			return false;
-		}
-		else {
-			QByteArray tmp = args.at(i).toUtf8();
-			char *name = tmp.data();
+		} else {
+			const QByteArray tmp = args.at(i).toUtf8();
+			const char *name = tmp.constData();
 			if (::fluid_is_soundfont(name)) {
 				if (++iSoundFontOverride == 1) {
-						m_pDefaultSetup->soundfonts.clear();
-						m_pDefaultSetup->bankoffsets.clear();
+					m_pDefaultSetup->soundfonts.clear();
+					m_pDefaultSetup->bankoffsets.clear();
 				}
 				m_pDefaultSetup->soundfonts.append(name);
 				m_pDefaultSetup->bankoffsets.append(QString::null);
@@ -810,6 +814,8 @@ bool qsynthOptions::deletePreset ( qsynthEngine *pEngine, const QString& sPreset
 
 void qsynthOptions::loadComboBoxHistory ( QComboBox *pComboBox, int iLimit )
 {
+	const bool bBlockSignals = pComboBox->blockSignals(true);
+
 	// Load combobox list from configuration settings file...
 	m_settings.beginGroup("/History/" + pComboBox->objectName());
 
@@ -817,7 +823,7 @@ void qsynthOptions::loadComboBoxHistory ( QComboBox *pComboBox, int iLimit )
 		pComboBox->setUpdatesEnabled(false);
 		pComboBox->setDuplicatesEnabled(false);
 		pComboBox->clear();
-		for (int i = 0; i < iLimit; i++) {
+		for (int i = 0; i < iLimit; ++i) {
 			const QString& sText = m_settings.value(
 				"/Item" + QString::number(i + 1)).toString();
 			if (sText.isEmpty())
@@ -828,36 +834,43 @@ void qsynthOptions::loadComboBoxHistory ( QComboBox *pComboBox, int iLimit )
 	}
 
 	m_settings.endGroup();
+
+	pComboBox->blockSignals(bBlockSignals);
 }
 
 
 void qsynthOptions::saveComboBoxHistory ( QComboBox *pComboBox, int iLimit )
 {
+	const bool bBlockSignals = pComboBox->blockSignals(true);
+
 	// Add current text as latest item...
-	const QString& sCurrentText = pComboBox->currentText();
+	const QString sCurrentText = pComboBox->currentText();
 	int iCount = pComboBox->count();
 	for (int i = 0; i < iCount; i++) {
 		const QString& sText = pComboBox->itemText(i);
 		if (sText == sCurrentText) {
 			pComboBox->removeItem(i);
-			iCount--;
+			--iCount;
 			break;
 		}
 	}
 	while (iCount >= iLimit)
 		pComboBox->removeItem(--iCount);
 	pComboBox->insertItem(0, sCurrentText);
-	iCount++;
+	pComboBox->setCurrentIndex(0);
+	++iCount;
 
 	// Save combobox list to configuration settings file...
 	m_settings.beginGroup("/History/" + pComboBox->objectName());
-	for (int i = 0; i < iCount; i++) {
+	for (int i = 0; i < iCount; ++i) {
 		const QString& sText = pComboBox->itemText(i);
 		if (sText.isEmpty())
 			break;
 		m_settings.setValue("/Item" + QString::number(i + 1), sText);
 	}
 	m_settings.endGroup();
+
+	pComboBox->blockSignals(bBlockSignals);
 }
 
 
@@ -897,16 +910,16 @@ void qsynthOptions::saveWidgetGeometry ( QWidget *pWidget, bool bVisible )
 	// (due to X11 window managers ideossincrasies, we better
 	// only save the form geometry while its up and visible)
 	if (pWidget) {
-			m_settings.beginGroup("/Geometry/" + pWidget->objectName());
-			const QPoint& wpos  = pWidget->pos();
-			const QSize&  wsize = pWidget->size();
-			if (!bVisible) bVisible = pWidget->isVisible();
-			m_settings.setValue("/x", wpos.x());
-			m_settings.setValue("/y", wpos.y());
-			m_settings.setValue("/width", wsize.width());
-			m_settings.setValue("/height", wsize.height());
-			m_settings.setValue("/visible", bVisible && !bStartMinimized);
-			m_settings.endGroup();
+		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
+		const QPoint& wpos  = pWidget->pos();
+		const QSize&  wsize = pWidget->size();
+		if (!bVisible) bVisible = pWidget->isVisible();
+		m_settings.setValue("/x", wpos.x());
+		m_settings.setValue("/y", wpos.y());
+		m_settings.setValue("/width", wsize.width());
+		m_settings.setValue("/height", wsize.height());
+		m_settings.setValue("/visible", bVisible && !bStartMinimized);
+		m_settings.endGroup();
 	}
 }
 
